@@ -13,14 +13,14 @@
 ##############################################################################
 """Security Settings Tests
 
-$Id: test_settings.py 95527 2009-01-29 20:47:44Z ctheune $
+$Id: test_settings.py 97975 2009-03-12 09:48:57Z nadako $
 """
 import unittest
-
-from zope.app.security.settings import Allow
 from cPickle import Pickler, Unpickler
 from StringIO import StringIO
 
+from zope.securitypolicy.interfaces import Allow
+
 class Test(unittest.TestCase):
 
     def testPickleUnpickle(self):
